.. BrewPi Service documentation master file, created by
   sphinx-quickstart on Sun Apr  3 20:31:26 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to BrewPi Service's documentation!
==========================================

Contents:

.. toctree::
   :maxdepth: 2

   development/core_notions
   development/hardware
   development/plugins
   development/roadmap
   development/communication


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

